// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KOSMINDOORMAP_VERSION_H
#define KOSMINDOORMAP_VERSION_H

#define KOSMINDOORMAP_VERSION_STRING "25.08.2"
#define KOSMINDOORMAP_VERSION_MAJOR 25
#define KOSMINDOORMAP_VERSION_MINOR 8
#define KOSMINDOORMAP_VERSION_PATCH 2
#define KOSMINDOORMAP_VERSION ((25<<16)|(8<<8)|(2))

#endif
